import { Number, Percentage } from "../numeric/index.js";
import type { Resolvable } from "../resolvable.js";
import { Value } from "../value.js";
import type { RGB } from "./rgb.js";
/**
 * @remarks
 * While colors can be calculated, they only use numbers and raw percentages.
 * Therefore, the calculations can be fully resolved at parse time and do not
 * need to be stored.
 *
 * @internal
 */
export declare abstract class Format<F extends string = string> extends Value<"color", false> implements Resolvable<RGB.Canonical, never> {
    private readonly _format;
    protected constructor(format: F);
    abstract get red(): Number.Canonical | Percentage.Canonical;
    abstract get green(): Number.Canonical | Percentage.Canonical;
    abstract get blue(): Number.Canonical | Percentage.Canonical;
    abstract resolve(): RGB.Canonical;
    toJSON(): Format.JSON<F>;
}
/**
 * @internal
 */
export declare namespace Format {
    interface JSON<F extends string = string> extends Value.JSON<"color"> {
        format: F;
    }
    /**
     * {@link https://drafts.csswg.org/css-color/#resolving-color-values}
     */
    function resolve(red: Number.Canonical | Percentage.Canonical, green: Number.Canonical | Percentage.Canonical, blue: Number.Canonical | Percentage.Canonical, alpha: Number.Canonical | Percentage.Canonical): [
        Percentage.Canonical,
        Percentage.Canonical,
        Percentage.Canonical,
        Percentage.Canonical
    ];
}
//# sourceMappingURL=format.d.ts.map