import type { Hash } from "@siteimprove/alfa-hash";
import type { Parser as CSSParser } from "../../../../syntax/index.js";
import { LengthPercentage } from "../../../numeric/index.js";
import type { PartiallyResolvable, Resolvable } from "../../../resolvable.js";
import { Value } from "../../../value.js";
/**
 * {@link https://drafts.csswg.org/css-images/#color-transition-hint}
 */
export declare class Hint<P extends LengthPercentage = LengthPercentage> extends Value<"hint", Value.HasCalculation<[P]>> implements Resolvable<Hint.Canonical, Hint.Resolver>, PartiallyResolvable<Hint.PartiallyResolved, Hint.PartialResolver> {
    static of<P extends LengthPercentage>(position: P): Hint<P>;
    private readonly _position;
    private constructor();
    get position(): P;
    resolve(resolver: Hint.Resolver): Hint.Canonical;
    partiallyResolve(resolver: Hint.PartialResolver): Hint.PartiallyResolved;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Hint.JSON;
    toString(): string;
}
export declare namespace Hint {
    type Canonical = Hint<LengthPercentage.Canonical>;
    type PartiallyResolved = Hint<LengthPercentage.PartiallyResolved>;
    interface JSON extends Value.JSON<"hint"> {
        position: LengthPercentage.JSON;
    }
    type Resolver = LengthPercentage.Resolver;
    type PartialResolver = LengthPercentage.PartialResolver;
    /**
     * {@link https://drafts.csswg.org/css-images/#typedef-linear-color-hint}
     */
    const parse: CSSParser<Hint>;
}
//# sourceMappingURL=hint.d.ts.map