import type { Hash } from "@siteimprove/alfa-hash";
import type { Parser as CSSParser } from "../../syntax/index.js";
import type { PartiallyResolvable, Resolvable } from "../resolvable.js";
import { Value } from "../value.js";
import { URL } from "./url.js";
import { Gradient } from "./gradient/index.js";
/**
 * {@link https://drafts.csswg.org/css-values/#images}
 *
 * @public
 */
export declare class Image<I extends URL | Gradient = URL | Gradient> extends Value<"image", Value.HasCalculation<[I]>> implements Resolvable<Image.Canonical, Image.Resolver>, PartiallyResolvable<Image.PartiallyResolved, Image.PartialResolver> {
    static of<I extends URL | Gradient>(image: I): Image<I>;
    private readonly _image;
    private constructor();
    get image(): I;
    resolve(resolver: Image.Resolver): Image.Canonical;
    partiallyResolve(resolver: Image.PartialResolver): Image.PartiallyResolved;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Image.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Image {
    type Canonical = Image<URL.Canonical | Gradient.Canonical>;
    type Resolver = URL.Resolver & Gradient.Resolver;
    interface JSON extends Value.JSON<"image"> {
        image: URL.JSON | Gradient.JSON;
    }
    type PartiallyResolved = Image<URL.Canonical | Gradient.PartiallyResolved>;
    type PartialResolver = URL.Resolver & Gradient.PartialResolver;
    function isImage<I extends URL | Gradient>(value: unknown): value is Image<I>;
    /**
     * {@link https://drafts.csswg.org/css-images/#typedef-image}
     */
    const parse: CSSParser<Image>;
}
//# sourceMappingURL=image.d.ts.map