import type { Hash } from "@siteimprove/alfa-hash";
import { Math as Calculation } from "../../calculation/index.js";
import { Integer as BaseInteger } from "../../calculation/numeric/index.js";
import { type Parser as CSSParser } from "../../syntax/index.js";
import type { Resolvable } from "../resolvable.js";
import { Numeric } from "./numeric.js";
/**
 * {@link https://drafts.csswg.org/css-values/#integers}
 *
 * @public
 */
export type Integer = Integer.Calculated | Integer.Fixed;
/**
 * {@link https://drafts.csswg.org/css-values/#integers}
 *
 * @public
 */
export declare namespace Integer {
    type Canonical = Fixed;
    /**
     * Integers that are the result of a calculation.
     */
    class Calculated extends Numeric.Calculated<"integer"> implements Resolvable<Canonical, never> {
        static of(value: Calculation<"number">): Calculated;
        private constructor();
        /**
         * @remarks
         * Numbers are rounded to the nearest integer upon resolving calculation
         *
         * {@link https://drafts.csswg.org/css-values/#calc-type-checking}
         */
        resolve(resolver?: Numeric.GenericResolver): Canonical;
        partiallyResolve(resolver?: Numeric.GenericResolver): Canonical;
        equals(value: unknown): value is this;
        toJSON(): Calculated.JSON;
    }
    /**
     * @public
     */
    namespace Calculated {
        interface JSON extends Numeric.Calculated.JSON<"integer"> {
        }
    }
    /**
     * Numbers that are a fixed (not calculated) value.
     */
    class Fixed extends Numeric.Fixed<"integer"> implements Resolvable<Canonical, never> {
        /**
         * {@link https://drafts.csswg.org/css-values/#css-round-to-the-nearest-integer}
         */
        static of(value: number | BaseInteger): Fixed;
        private constructor();
        resolve(): this;
        partiallyResolve(): this;
        scale(factor: number): Fixed;
        /**
         * @internal
         */
        toBase(): BaseInteger;
        equals(value: unknown): value is this;
        hash(hash: Hash): void;
        toJSON(): Fixed.JSON;
    }
    /**
     * @public
     */
    namespace Fixed {
        interface JSON extends Numeric.Fixed.JSON<"integer"> {
        }
    }
    function isCalculated(value: unknown): value is Calculated;
    function isFixed(value: unknown): value is Fixed;
    function isInteger(value: unknown): value is Integer;
    function of(value: number): Fixed;
    function of(value: BaseInteger): Fixed;
    function of(value: Calculation<"number">): Calculated;
    /**
     * {@link https://drafts.csswg.org/css-values/#number-value}
     */
    const parse: CSSParser<Integer>;
}
//# sourceMappingURL=integer.d.ts.map