import { Math } from "../../calculation/index.js";
import { Number as BaseNumber } from "../../calculation/numeric/index.js";
import { type Parser as CSSParser } from "../../syntax/index.js";
import type { Resolvable } from "../resolvable.js";
import { Numeric } from "./numeric.js";
/**
 * {@link https://drafts.csswg.org/css-values/#numbers}
 *
 * @public
 */
export type Number = Number.Calculated | Number.Fixed;
/**
 * {@link https://drafts.csswg.org/css-values/#numbers}
 *
 * @public
 */
export declare namespace Number {
    type Canonical = Fixed;
    /**
     * Numbers that are the result of a calculation.
     */
    class Calculated extends Numeric.Calculated<"number"> implements Resolvable<Canonical, never> {
        static of(value: Math<"number">): Calculated;
        private constructor();
        resolve(resolver?: Numeric.GenericResolver): Canonical;
        partiallyResolve(resolver?: Numeric.GenericResolver): Canonical;
        equals(value: unknown): value is this;
        toJSON(): Calculated.JSON;
    }
    /**
     * @public
     */
    namespace Calculated {
        interface JSON extends Numeric.Calculated.JSON<"number"> {
        }
    }
    /**
     * Numbers that are a fixed (not calculated) value.
     */
    class Fixed extends Numeric.Fixed<"number"> implements Resolvable<Canonical, never> {
        static of(value: number | BaseNumber): Fixed;
        private constructor();
        resolve(): this;
        partiallyResolve(): this;
        scale(factor: number): Fixed;
        /**
         * @internal
         */
        toBase(): BaseNumber;
        equals(value: unknown): value is this;
        toJSON(): Fixed.JSON;
    }
    /**
     * @public
     */
    namespace Fixed {
        interface JSON extends Numeric.Fixed.JSON<"number"> {
        }
    }
    function isCalculated(value: unknown): value is Calculated;
    function isFixed(value: unknown): value is Fixed;
    function isNumber(value: unknown): value is Number;
    function of(value: number): Fixed;
    function of(value: BaseNumber): Fixed;
    function of(value: Math<"number">): Calculated;
    /**
     * {@link https://drafts.csswg.org/css-values/#number-value}
     */
    const parse: CSSParser<Number>;
    /**
     * @remarks
     * Zero values must be true 0, not calculations evaluating to 0.
     *
     * {@link https://drafts.csswg.org/css-values/#zero-value}
     */
    const parseZero: CSSParser<Fixed>;
}
//# sourceMappingURL=number.d.ts.map