import { Array } from "@siteimprove/alfa-array";
import type { Hash } from "@siteimprove/alfa-hash";
import type { Iterable } from "@siteimprove/alfa-iterable";
import type { Serializable } from "@siteimprove/alfa-json";
import type { Option } from "@siteimprove/alfa-option";
import { type Parser as CSSParser } from "../../syntax/index.js";
import { Keyword } from "../keyword.js";
import { LengthPercentage } from "../numeric/index.js";
import type { PartiallyResolvable, Resolvable } from "../resolvable.js";
import { Value } from "../value.js";
import { BasicShape } from "./basic-shape.js";
/**
 * {@link https://drafts.csswg.org/css-shapes/#funcdef-polygon}
 *
 * @public
 */
export declare class Polygon<F extends Polygon.Fill = Polygon.Fill, V extends LengthPercentage = LengthPercentage> extends BasicShape<"polygon", Value.HasCalculation<[V]>> implements Resolvable<Polygon.Canonical, Polygon.Resolver>, PartiallyResolvable<Polygon.PartiallyResolved, Polygon.PartialResolver> {
    static of<F extends Polygon.Fill = Polygon.Fill, V extends LengthPercentage = LengthPercentage>(fill: Option<F>, vertices: Iterable<Polygon.Vertex<V>>): Polygon<F, V>;
    private readonly _fill;
    private readonly _vertices;
    private constructor();
    get fill(): Option<F>;
    get vertices(): ReadonlyArray<Polygon.Vertex<V>>;
    resolve(resolver: Polygon.Resolver): Polygon.Canonical;
    partiallyResolve(resolver: Polygon.PartialResolver): Polygon.PartiallyResolved;
    equals(value: Polygon): boolean;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Polygon.JSON<F, V>;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Polygon {
    type Canonical = Polygon<Fill, LengthPercentage.Canonical>;
    type PartiallyResolved = Polygon<Fill, LengthPercentage.PartiallyResolved>;
    type Fill = Keyword<"nonzero"> | Keyword<"evenodd">;
    type Vertex<V extends LengthPercentage = LengthPercentage> = readonly [
        V,
        V
    ];
    interface JSON<F extends Fill = Fill, V extends LengthPercentage = LengthPercentage> extends BasicShape.JSON<"polygon"> {
        fill: Option.JSON<F>;
        vertices: Array<Serializable.ToJSON<Vertex<V>>>;
    }
    type Resolver = LengthPercentage.Resolver;
    type PartialResolver = LengthPercentage.PartialResolver;
    function isPolygon(value: unknown): value is Polygon;
    const parse: CSSParser<Polygon>;
}
//# sourceMappingURL=polygon.d.ts.map