import { Parser } from "@siteimprove/alfa-parser";
import type { Slice } from "@siteimprove/alfa-slice";
import type { Token } from "../../syntax/index.js";
import { List } from "../collection/index.js";
import type { Angle, Length, LengthPercentage, Number } from "../numeric/index.js";
import { Matrix } from "./matrix.js";
import { Perspective } from "./perspective.js";
import { Rotate } from "./rotate.js";
import { Scale } from "./scale.js";
import { Skew } from "./skew.js";
import { Translate } from "./translate.js";
/**
 * @public
 */
export type Transform = Matrix | Perspective | Rotate | Scale | Skew | Translate;
/**
 * @public
 */
export declare namespace Transform {
    type Canonical = Matrix.Canonical | Perspective.Canonical | Rotate.Canonical | Scale.Canonical | Skew.Canonical | Translate.Canonical;
    type Resolver = LengthPercentage.Resolver;
    function resolve(resolver: Resolver): (value: Transform) => Canonical;
    type PartiallyResolved = Matrix.Canonical | Perspective.Canonical | Rotate.Canonical | Scale.Canonical | Skew.Canonical | Translate.PartiallyResolved;
    type PartialResolver = Translate.PartialResolver;
    function partiallyResolve(resolver: PartialResolver): (value: Transform) => PartiallyResolved;
    function matrix(...values: Matrix.Values<Number>): Matrix;
    function perspective<D extends Length>(depth: D): Perspective<D>;
    function rotate(x: Number, y: Number, z: Number, angle: Angle): Rotate;
    function scale(x: Number, y: Number): Scale;
    function skew(x: Angle, y: Angle): Skew;
    function translate<X extends LengthPercentage, Y extends LengthPercentage, Z extends Length>(x: X, y: Y, z: Z): Translate<X, Y, Z>;
    /**
     * {@link https://drafts.csswg.org/css-transforms/#typedef-transform-function}
     *
     * @internal
     */
    const parse: Parser<Slice<Token>, Transform, string, []>;
    /**
     * {@link https://drafts.csswg.org/css-transforms/#typedef-transform-list}
     */
    const parseList: import("../../syntax/parser.js").Parser<List<Transform>>;
}
//# sourceMappingURL=transform.d.ts.map